Router

Struct Router 

pub struct Router { /* private fields */ }
The router manages provider selection and fallback.

Implementations

Source

impl Router

pub fn new(routes: Vec<ProviderRoute>, strategy: RoutingStrategy) -> Self

Create a new router with the given routes and strategy.

pub fn set_health_map(&mut self, map: HealthMap)

Set the health map for background health check filtering.

pub fn select(&self, model: &str) -> Option<&ProviderRoute>

Select the best provider for a given model.

pub fn report_latency( &self, provider: ProviderType, base_url: &str, latency_ms: u64, )

Report observed latency for a provider, updating an exponential moving average.

pub fn reload(&mut self, routes: Vec<ProviderRoute>, strategy: RoutingStrategy)

Replace routes and strategy atomically.

pub fn routes(&self) -> &[ProviderRoute]

All configured routes.